@@ -7,7 +7,7 @@ use base qw/Template::Benchmark::Engine/;
 
 use HTML::Template;
 
-our $VERSION = '1.06_01';
+our $VERSION = '1.07_01';
 
 our %feature_syntaxes = (
     literal_text              =>
@@ -90,7 +90,7 @@ sub benchmark_functions_for_uncached_string
                     );
                 $t->param( $_[ 1 ] );
                 $t->param( $_[ 2 ] );
-                $t->output();
+                \$t->output();
             },
         } );
 }
@@ -116,7 +116,7 @@ sub benchmark_functions_for_uncached_disk
                     );
                 $t->param( $_[ 1 ] );
                 $t->param( $_[ 2 ] );
-                $t->output();
+                \$t->output();
             },
         } );
 }
@@ -143,7 +143,7 @@ sub benchmark_functions_for_disk_cache
                     );
                 $t->param( $_[ 1 ] );
                 $t->param( $_[ 2 ] );
-                $t->output();
+                \$t->output();
             },
         } );
 }
@@ -173,7 +173,7 @@ sub benchmark_functions_for_shared_memory_cache
                     );
                 $t->param( $_[ 1 ] );
                 $t->param( $_[ 2 ] );
-                $t->output();
+                \$t->output();
             },
         } );
 }
@@ -199,7 +199,7 @@ sub benchmark_functions_for_memory_cache
                     );
                 $t->param( $_[ 1 ] );
                 $t->param( $_[ 2 ] );
-                $t->output();
+                \$t->output();
             },
         } );
 }
