@@ -7,7 +7,7 @@ use base qw/Template::Benchmark::Engine/;
 
 use Text::Clevy;
 
-our $VERSION = '1.06_01';
+our $VERSION = '1.07_01';
 
 our %feature_syntaxes = (
     literal_text              =>
@@ -112,7 +112,7 @@ sub benchmark_functions_for_uncached_string
                         substr => sub { substr( $_[ 0 ], $_[ 1 ], $_[ 2 ] ) },
                         },
                     );
-                $t->render_string( $_[ 0 ], { %{$_[ 1 ]}, %{$_[ 2 ]} } );
+                \$t->render_string( $_[ 0 ], { %{$_[ 1 ]}, %{$_[ 2 ]} } );
             },
         } );
 }
@@ -135,7 +135,7 @@ sub benchmark_functions_for_uncached_disk
                         substr => sub { substr( $_[ 0 ], $_[ 1 ], $_[ 2 ] ) },
                         },
                     );
-                $t->render( $_[ 0 ], { %{$_[ 1 ]}, %{$_[ 2 ]} } );
+                \$t->render( $_[ 0 ], { %{$_[ 1 ]}, %{$_[ 2 ]} } );
             },
         } );
 }
@@ -159,7 +159,7 @@ sub benchmark_functions_for_disk_cache
                         substr => sub { substr( $_[ 0 ], $_[ 1 ], $_[ 2 ] ) },
                         },
                     );
-                $t->render( $_[ 0 ], { %{$_[ 1 ]}, %{$_[ 2 ]} } );
+                \$t->render( $_[ 0 ], { %{$_[ 1 ]}, %{$_[ 2 ]} } );
             },
         } );
 }
@@ -197,7 +197,7 @@ sub benchmark_functions_for_instance_reuse
                         substr => sub { substr( $_[ 0 ], $_[ 1 ], $_[ 2 ] ) },
                         },
                     ) unless $t;
-                $t->render( $_[ 0 ], { %{$_[ 1 ]}, %{$_[ 2 ]} } );
+                \$t->render( $_[ 0 ], { %{$_[ 1 ]}, %{$_[ 2 ]} } );
             },
         } );
 }
